@@ -22,24 +22,28 @@ def _kepler_equation_prime_hyper(F, M, ecc):
     return ecc * np.cosh(F) - 1
 
 
-@jit
-def newton(regime, x0, args=(), tol=1.48e-08, maxiter=50):
-    p0 = 1.0 * x0
-    for iter in range(maxiter):
-        if regime == "hyperbolic":
-            fval = _kepler_equation_hyper(p0, *args)
-            fder = _kepler_equation_prime_hyper(p0, *args)
-        else:
-            fval = _kepler_equation(p0, *args)
-            fder = _kepler_equation_prime(p0, *args)
+def newton_factory(func, fprime):
+    @jit
+    def jit_newton_wrapper(x0, args=(), tol=1.48e-08, maxiter=50):
+        p0 = float(x0)
+        for _ in range(maxiter):
+            fval = func(p0, *args)
+            fder = fprime(p0, *args)
+            newton_step = fval / fder
+            p = p0 - newton_step
+            if abs(p - p0) < tol:
+                return p
+            p0 = p
 
-        newton_step = fval / fder
-        p = p0 - newton_step
-        if abs(p - p0) < tol:
-            return p
-        p0 = p
+        return np.nan
 
-    return np.nan
+    return jit_newton_wrapper
+
+
+_newton_elliptic = newton_factory(_kepler_equation, _kepler_equation_prime)
+_newton_hyperbolic = newton_factory(
+    _kepler_equation_hyper, _kepler_equation_prime_hyper
+)
 
 
 @jit
@@ -281,12 +285,11 @@ def M_to_E(M, ecc):
     This uses a Newton iteration on the Kepler equation.
 
     """
-    assert -np.pi <= M <= np.pi
-    if ecc < 0.8:
-        E0 = M
+    if -np.pi < M < 0 or np.pi < M:
+        E0 = M - ecc
     else:
-        E0 = np.pi * np.sign(M)
-    E = newton("elliptic", E0, args=(M, ecc))
+        E0 = M + ecc
+    E = _newton_elliptic(E0, args=(M, ecc))
     return E
 
 
@@ -312,7 +315,7 @@ def M_to_F(M, ecc):
 
     """
     F0 = np.arcsinh(M / ecc)
-    F = newton("hyperbolic", F0, args=(M, ecc), maxiter=100)
+    F = _newton_hyperbolic(F0, args=(M, ecc), maxiter=100)
     return F
 
 
