@@ -2,13 +2,15 @@
 convert between different elements that define the orbit of a body.
 """
 
+import sys
+
 import numpy as np
 from numba import njit as jit, prange
 from numpy import cos, cross, sin, sqrt
 from numpy.linalg import norm
 
-from .angles import E_to_nu, F_to_nu
-from .util import rotation_matrix
+from poliastro.core.angles import E_to_nu, F_to_nu
+from poliastro.core.util import rotation_matrix
 
 
 @jit
@@ -100,8 +102,8 @@ def coe2rv(k, p, ecc, inc, raan, argp, nu):
         Eccentricity.
     inc : float
         Inclination (rad).
-    omega : float
-        Longitude of ascending node (rad).
+    raan : float
+        Longitude of ascending node, omega (rad).
     argp : float
         Argument of perigee (rad).
     nu : float
@@ -146,7 +148,7 @@ def coe2rv(k, p, ecc, inc, raan, argp, nu):
     return ijk
 
 
-@jit(parallel=True)
+@jit(parallel=sys.maxsize > 2 ** 31)
 def coe2rv_many(k, p, ecc, inc, raan, argp, nu):
 
     n = nu.shape[0]
