@@ -2,8 +2,7 @@
 
 """
 import numpy as np
-
-from ._jit import jit
+from numba import njit as jit
 
 
 @jit
