@@ -1,7 +1,7 @@
 import numpy as np
+from numba import njit as jit
 
-from .._jit import jit
-from ..angles import (
+from poliastro.core.angles import (
     D_to_M,
     D_to_nu,
     E_to_M,
@@ -15,7 +15,7 @@ from ..angles import (
     nu_to_E,
     nu_to_F,
 )
-from ..elements import coe2rv, rv2coe
+from poliastro.core.elements import coe2rv, rv2coe
 
 
 @jit
@@ -283,6 +283,17 @@ def nu_from_delta_t(delta_t, ecc, k=1.0, q=1.0, delta=1e-2):
     return nu
 
 
+@jit
+def farnocchia_coe(k, p, ecc, inc, raan, argp, nu, tof):
+
+    q = p / (1 + ecc)
+
+    delta_t0 = delta_t_from_nu(nu, ecc, k, q)
+    delta_t = delta_t0 + tof
+
+    return nu_from_delta_t(delta_t, ecc, k, q)
+
+
 @jit
 def farnocchia(k, r0, v0, tof):
     r"""Propagates orbit using mean motion.
@@ -300,9 +311,9 @@ def farnocchia(k, r0, v0, tof):
     ----------
     k : float
         Standar Gravitational parameter
-    r0 : ~astropy.units.Quantity
+    r0 : ~np.array
         Initial position vector wrt attractor center.
-    v0 : ~astropy.units.Quantity
+    v0 : ~np.array
         Initial velocity vector.
     tof : float
         Time of flight (s).
@@ -317,11 +328,6 @@ def farnocchia(k, r0, v0, tof):
 
     # get the initial true anomaly and orbit parameters that are constant over time
     p, ecc, inc, raan, argp, nu0 = rv2coe(k, r0, v0)
-    q = p / (1 + ecc)
-
-    delta_t0 = delta_t_from_nu(nu0, ecc, k, q)
-    delta_t = delta_t0 + tof
-
-    nu = nu_from_delta_t(delta_t, ecc, k, q)
+    nu = farnocchia_coe(k, p, ecc, inc, raan, argp, nu0, tof)
 
     return coe2rv(k, p, ecc, inc, raan, argp, nu)
