@@ -1,8 +1,7 @@
 from math import gamma
 
 import numpy as np
-
-from ._jit import jit
+from numba import njit as jit
 
 
 @jit
