@@ -23,7 +23,7 @@ def lambert(k, r0, r, tof, short=True, numiter=35, rtol=1e-8):
         Final position (km).
     tof : ~astropy.units.Quantity
         Time of flight (s).
-    short : boolean, optional
+    short : bool, optional
         Find out the short path, default to True. If False, find long path.
     numiter : int, optional
         Maximum number of iterations, default to 35.
@@ -42,10 +42,10 @@ def lambert(k, r0, r, tof, short=True, numiter=35, rtol=1e-8):
     not supported.
 
     """
-    k_ = k.to(u.km ** 3 / u.s ** 2).value
-    r0_ = r0.to(u.km).value
-    r_ = r.to(u.km).value
-    tof_ = tof.to(u.s).value
+    k_ = k.to_value(u.km ** 3 / u.s ** 2)
+    r0_ = r0.to_value(u.km)
+    r_ = r.to_value(u.km)
+    tof_ = tof.to_value(u.s)
 
     v0, v = vallado_fast(k_, r0_, r_, tof_, short, numiter, rtol)
 
