@@ -6,11 +6,11 @@ import numpy as np
 from astropy import units as u
 from astropy.coordinates import CartesianRepresentation
 
-from ..ephem import Ephem
-from ..frames import Planes
-from ..twobody.mean_elements import get_mean_elements
-from ..util import norm, time_range
-from .util import BODY_COLORS, generate_label
+from poliastro.ephem import Ephem
+from poliastro.frames import Planes
+from poliastro.plotting.util import BODY_COLORS, generate_label
+from poliastro.twobody.mean_elements import get_mean_elements
+from poliastro.util import norm, time_range
 
 
 class Trajectory(
@@ -77,7 +77,9 @@ class BaseOrbitPlotter:
         self._clear_attractor()
 
         self._draw_sphere(
-            self._attractor_radius, color, self._attractor.name,
+            self._attractor_radius,
+            color,
+            self._attractor.name,
         )
 
     def _redraw(self):
@@ -87,9 +89,15 @@ class BaseOrbitPlotter:
     def _get_colors(self, color, trail):
         raise NotImplementedError
 
+    def _draw_marker(self, maker, size, color, name, center=None):
+        raise NotImplementedError
+
     def _draw_point(self, radius, color, name, center=None):
         raise NotImplementedError
 
+    def _draw_impulse(self, color, name, center=None):
+        raise NotImplementedError
+
     def _draw_sphere(self, radius, color, name, center=None):
         raise NotImplementedError
 
@@ -143,6 +151,79 @@ class BaseOrbitPlotter:
             coordinates, None, label=str(label), colors=colors, dashed=False
         )
 
+    def _plot_maneuver(
+        self, initial_orbit, maneuver, *, label=None, color=None, trail=False
+    ):
+        if self._attractor is None:
+            raise ValueError(
+                "An attractor must be set up first, please use "
+                "set_attractor(Major_Body) or plot(orbit)"
+            )
+
+        # Apply the maneuver, collect all intermediate states and allocate the
+        # final coordinates list array
+        *maneuver_phases, final_phase = initial_orbit.apply_maneuver(
+            maneuver, intermediate=True
+        )
+
+        if len(maneuver_phases) == 0:
+            # For single-impulse maneuver only draw the impulse marker
+            impulse_label = f"Impulse 1 - {label}"
+            impulse_lines = ([self._draw_impulse(color, impulse_label, final_phase.r)],)
+            return [(impulse_label, impulse_lines)]
+        else:
+            # Declare for holding (label, lines) for each impulse and trajectory
+            lines_list = []
+
+            # Collect the coordinates for the different maneuver phases
+            for ith_impulse, orbit_phase in enumerate(maneuver_phases):
+
+                # Plot the impulse marker and collect its label and lines
+                impulse_label = f"Impulse {ith_impulse + 1} - {label}"
+                impulse_lines = (
+                    [self._draw_impulse(color, impulse_label, orbit_phase.r)],
+                )
+                lines_list.append((impulse_label, impulse_lines))
+
+                # HACK: if no color is provided, get the one randomly generated
+                # for previous impulse lines
+                color = impulse_lines[0][0].get_color() if color is None else color
+
+                # Get the propagation time required before next impulse
+                time_to_next_impulse, _ = maneuver.impulses[ith_impulse + 1]
+
+                # Compute the minimum and maximum anomalies
+                min_nu = orbit_phase.nu
+                # High level, but inefficient way of solving the Kepler equation,
+                # which is what farnocchia_coe does:
+                # tp0 = delta_t_from_nu(nu, ecc, k, q)
+                # tp = tp0 + tof
+                # max_nu = nu_from_delta_t(tp, ecc, k, q)
+                max_nu = orbit_phase.propagate(time_to_next_impulse).nu
+
+                # Collect the coordinate points for the i-th orbit phase
+                # We use .sample rather than poliastro.twobody.propagation.propagate
+                # because the latter samples time uniformly
+                # and therefore generates a sharp curve close to the perigee,
+                # and that's also why I need to compute the anomalies outside,
+                # see https://github.com/poliastro/poliastro/issues/1364
+                phase_coordinates = orbit_phase.sample(
+                    min_anomaly=min_nu, max_anomaly=max_nu
+                )
+
+                # Plot the phase trajectory and collect its label and lines
+                trajectory_lines = self._plot_trajectory(
+                    phase_coordinates, label=label, color=color, trail=trail
+                )
+                lines_list.append((label, trajectory_lines))
+
+            # Finally, draw the impulse at the very beginning of the final phase
+            impulse_label = f"Impulse {ith_impulse + 2} - {label}"
+            impulse_lines = ([self._draw_impulse(color, impulse_label, final_phase.r)],)
+            lines_list.append((impulse_label, impulse_lines))
+
+        return lines_list
+
     def _plot(self, orbit, *, label=None, color=None, trail=False):
         colors = self._get_colors(color, trail)
 
@@ -158,7 +239,13 @@ class BaseOrbitPlotter:
         )
 
     def _plot_body_orbit(
-        self, body, epoch, *, label=None, color=None, trail=False,
+        self,
+        body,
+        epoch,
+        *,
+        label=None,
+        color=None,
+        trail=False,
     ):
         if color is None:
             color = BODY_COLORS.get(body.name)
@@ -212,9 +299,9 @@ class BaseOrbitPlotter:
         ----------
         coordinates : ~astropy.coordinates.CartesianRepresentation
             Trajectory to plot.
-        label : string, optional
+        label : str, optional
             Label of the trajectory.
-        color : string, optional
+        color : str, optional
             Color of the trajectory.
         trail : bool, optional
             Fade the orbit trail, default to False.
@@ -224,6 +311,31 @@ class BaseOrbitPlotter:
         # This behavior might be overriden by subclasses
         self._plot_trajectory(coordinates, label=label, color=color, trail=trail)
 
+    def plot_maneuver(
+        self, initial_orbit, maneuver, label=None, color=None, trail=False
+    ):
+        """Plots the maneuver trajectory applied to the provided initial orbit.
+
+        Parameters
+        ----------
+        initial_orbit: ~poliastro.twobody.orbit.Orbit
+            The base orbit for which the maneuver will be applied.
+        manuever: ~poliastro.maneuver.Maneuver
+            The maneuver to be plotted.
+        label : str, optional
+            Label of the trajectory.
+        color : str, optional
+            Color of the trajectory.
+        trail : bool, optional
+            Fade the orbit trail, default to False.
+
+        """
+        # Do not return the result of self._plot
+        # This behavior might be overriden by subclasses
+        self._plot_maneuver(
+            initial_orbit, maneuver, label=label, color=color, trail=trail
+        )
+
     def plot(self, orbit, *, label=None, color=None, trail=False):
         """Plots state and osculating orbit in their plane.
 
@@ -231,9 +343,9 @@ class BaseOrbitPlotter:
         ----------
         orbit : ~poliastro.twobody.orbit.Orbit
             Orbit to plot.
-        label : string, optional
+        label : str, optional
             Label of the orbit.
-        color : string, optional
+        color : str, optional
             Color of the line and the position.
         trail : bool, optional
             Fade the orbit trail, default to False.
@@ -244,7 +356,13 @@ class BaseOrbitPlotter:
         self._plot(orbit, label=label, color=color, trail=trail)
 
     def plot_body_orbit(
-        self, body, epoch, *, label=None, color=None, trail=False,
+        self,
+        body,
+        epoch,
+        *,
+        label=None,
+        color=None,
+        trail=False,
     ):
         """Plots complete revolution of body and current position.
 
@@ -256,7 +374,7 @@ class BaseOrbitPlotter:
             Epoch of current position.
         label : str, optional
             Label of the orbit, default to the name of the body.
-        color : string, optional
+        color : str, optional
             Color of the line and the position.
         trail : bool, optional
             Fade the orbit trail, default to False.
@@ -277,7 +395,7 @@ class BaseOrbitPlotter:
             Epoch of the current position, none will be used if not given.
         label : str, optional
             Label of the orbit, default to the name of the body.
-        color : string, optional
+        color : str, optional
             Color of the line and the position.
         trail : bool, optional
             Fade the orbit trail, default to False.
@@ -353,10 +471,28 @@ class Mixin2D:
             Epoch of current position.
 
         """
+        from warnings import warn
+
+        from astropy import time
+
+        from poliastro.bodies import Sun
         from poliastro.twobody import Orbit
 
+        from ..warnings import TimeScaleWarning
+
+        if not epoch:
+            epoch = time.Time.now().tdb
+        elif epoch.scale != "tdb":
+            epoch = epoch.tdb
+            warn(
+                "Input time was converted to scale='tdb' with value "
+                f"{epoch.tdb.value}. Use Time(..., scale='tdb') instead.",
+                TimeScaleWarning,
+                stacklevel=2,
+            )
+
         with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            orbit = Orbit.from_body_ephem(body, epoch).change_plane(self.plane)  # type: ignore
+            ephem = Ephem.from_body(body, epoch, attractor=Sun, plane=self.plane)  # type: ignore
+            orbit = Orbit.from_ephem(Sun, ephem, epoch).change_plane(self.plane)  # type: ignore
 
         self.set_orbit_frame(orbit)
