@@ -8,23 +8,17 @@ u_km3s2 = u.km ** 3 / u.s ** 2
 
 
 def circular_velocity(k, a):
-    """Circular velocity for a given body (k) and semimajor axis (a).
-
-    """
-    return circular_velocity_fast(k.to(u_km3s2).value, a.to(u.km).value) * u_kms
+    """Circular velocity for a given body (k) and semimajor axis (a)."""
+    return circular_velocity_fast(k.to_value(u_km3s2), a.to_value(u.km)) * u_kms
 
 
 def mean_motion(k, a):
-    """Mean motion given body (k) and semimajor axis (a).
-
-    """
+    """Mean motion given body (k) and semimajor axis (a)."""
     return np.sqrt(k / abs(a ** 3)).to(1 / u.s) * u.rad
 
 
 def period(k, a):
-    """Period given body (k) and semimajor axis (a).
-
-    """
+    """Period given body (k) and semimajor axis (a)."""
     n = mean_motion(k, a)
     return 2 * np.pi * u.rad / n
 
@@ -98,7 +92,7 @@ def get_eccentricity_critical_inc(ecc=None):
 
     Parameters
     ----------
-    ecc: : ~astropy.units.Quantity, optional
+    ecc: ~astropy.units.Quantity, optional
         Eccentricity, default to None.
 
     """
