@@ -3,7 +3,6 @@ from collections import OrderedDict
 from functools import partial
 from unittest import mock
 
-import hypothesis.strategies as st
 import matplotlib
 import numpy as np
 import pytest
@@ -16,7 +15,7 @@ from astropy.coordinates import (
 )
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.time import Time
-from hypothesis import example, given, settings
+from hypothesis import example, given, settings, strategies as st
 from numpy.testing import assert_allclose, assert_array_equal
 
 from poliastro.bodies import (
@@ -27,7 +26,6 @@ from poliastro.bodies import (
     Mercury,
     Moon,
     Neptune,
-    Pluto,
     Saturn,
     Sun,
     Uranus,
@@ -41,7 +39,6 @@ from poliastro.frames.enums import Planes
 from poliastro.frames.equatorial import (
     GCRS,
     HCRS,
-    ICRS,
     JupiterICRS,
     MarsICRS,
     MercuryICRS,
@@ -53,11 +50,7 @@ from poliastro.frames.equatorial import (
 from poliastro.frames.util import get_frame
 from poliastro.twobody.angles import E_to_M, nu_to_E
 from poliastro.twobody.orbit import Orbit
-from poliastro.warnings import (
-    OrbitSamplingWarning,
-    PatchedConicsWarning,
-    TimeScaleWarning,
-)
+from poliastro.warnings import OrbitSamplingWarning, PatchedConicsWarning
 
 
 @pytest.fixture()
@@ -86,7 +79,9 @@ def test_default_time_for_new_state():
     _a = 1.0 * u.deg  # Unused angle
     _body = Sun  # Unused body
     expected_epoch = J2000
-    ss = Orbit.from_classical(_body, _d, _, _a, _a, _a, _a)
+    ss = Orbit.from_classical(
+        attractor=_body, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+    )
     assert ss.epoch == expected_epoch
 
 
@@ -96,7 +91,9 @@ def test_state_raises_unitserror_if_elements_units_are_wrong():
     _a = 1.0 * u.deg  # Unused angle
     wrong_angle = 1.0 * u.AU
     with pytest.raises(u.UnitsError) as excinfo:
-        Orbit.from_classical(Sun, _d, _, _a, _a, _a, wrong_angle)
+        Orbit.from_classical(
+            attractor=Sun, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=wrong_angle
+        )
     assert (
         "UnitsError: Argument 'nu' to function 'from_classical' must be in units convertible to 'rad'."
         in excinfo.exconly()
@@ -109,7 +106,9 @@ def test_orbit_from_classical_wraps_out_of_range_anomaly_and_warns():
     _a = 1.0 * u.deg  # Unused angle
     out_angle = np.pi * u.rad
     with pytest.warns(UserWarning, match="Wrapping true anomaly to -π <= nu < π"):
-        Orbit.from_classical(Sun, _d, _, _a, _a, _a, out_angle)
+        Orbit.from_classical(
+            attractor=Sun, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=out_angle
+        )
 
 
 def test_state_raises_unitserror_if_rv_units_are_wrong():
@@ -129,7 +128,9 @@ def test_parabolic_elements_fail_early():
     _d = 1.0 * u.AU  # Unused distance
     _a = 1.0 * u.deg  # Unused angle
     with pytest.raises(ValueError) as excinfo:
-        Orbit.from_classical(attractor, _d, ecc, _a, _a, _a, _a)
+        Orbit.from_classical(
+            attractor=attractor, a=_d, ecc=ecc, inc=_a, raan=_a, argp=_a, nu=_a
+        )
     assert (
         "ValueError: For parabolic orbits use Orbit.parabolic instead"
         in excinfo.exconly()
@@ -143,7 +144,9 @@ def test_bad_inclination_raises_exception():
     _body = Sun  # Unused body
     bad_inc = 200 * u.deg
     with pytest.raises(ValueError) as excinfo:
-        Orbit.from_classical(_body, _d, _, bad_inc, _a, _a, _a)
+        Orbit.from_classical(
+            attractor=_body, a=_d, ecc=_, inc=bad_inc, raan=_a, argp=_a, nu=_a
+        )
     assert (
         "ValueError: Inclination must be between 0 and 180 degrees" in excinfo.exconly()
     )
@@ -156,7 +159,9 @@ def test_bad_hyperbolic_raises_exception():
     _a = 1.0 * u.deg  # Unused angle
     _body = Sun  # Unused body
     with pytest.raises(ValueError) as excinfo:
-        Orbit.from_classical(_body, bad_a, ecc, _inc, _a, _a, _a)
+        Orbit.from_classical(
+            attractor=_body, a=bad_a, ecc=ecc, inc=_inc, raan=_a, argp=_a, nu=_a
+        )
     assert "Hyperbolic orbits have negative semimajor axis" in excinfo.exconly()
 
 
@@ -164,36 +169,31 @@ def test_apply_maneuver_changes_epoch():
     _d = 1.0 * u.AU  # Unused distance
     _ = 0.5 * u.one  # Unused dimensionless value
     _a = 1.0 * u.deg  # Unused angle
-    ss = Orbit.from_classical(Sun, _d, _, _a, _a, _a, _a)
+    ss = Orbit.from_classical(
+        attractor=Sun, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+    )
     dt = 1 * u.h
     dv = [0, 0, 0] * u.km / u.s
     orbit_new = ss.apply_maneuver([(dt, dv)])
     assert orbit_new.epoch == ss.epoch + dt
 
 
-def test_orbit_from_ephem_with_no_epoch_is_today():
-    # This is not that obvious http://stackoverflow.com/q/6407362/554319
-    body = Earth
-    ss = Orbit.from_body_ephem(body)
-    assert (Time.now() - ss.epoch).sec < 1
+def test_apply_maneuver_returns_intermediate_states_if_true():
+    _d = 1.0 * u.AU  # Unused distance
+    _ = 0.5 * u.one  # Unused dimensionless value
+    _a = 1.0 * u.deg  # Unused angle
+    ss = Orbit.from_classical(
+        attractor=Sun, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+    )
+    dt1 = 0.5 * u.h
+    dv1 = [5, 0, 10] * u.km / u.s
+    dt2 = 0.5 * u.h
+    dv2 = [0, 5, 10] * u.km / u.s
 
+    states = ss.apply_maneuver([(dt1, dv1), (dt2, dv2)], intermediate=True)
 
-def test_from_ephem_raises_warning_if_time_is_not_tdb_with_proper_time(recwarn):
-    body = Earth
-    epoch = Time("2017-09-29 07:31:26", scale="utc")
-    expected_epoch_string = "2017-09-29 07:32:35.182"  # epoch.tdb.value
-
-    Orbit.from_body_ephem(body, epoch)
-
-    w = recwarn.pop(TimeScaleWarning)
-    assert expected_epoch_string in str(w.message)
-
-
-@pytest.mark.parametrize("body", [Moon, Pluto])
-def test_from_ephem_raises_error_for_pluto_moon(body):
-    with pytest.raises(RuntimeError) as excinfo:
-        Orbit.from_body_ephem(body)
-    assert "To compute the position and velocity" in excinfo.exconly()
+    assert len(states) == 2
+    assert states[-1].epoch == ss.epoch + dt1 + dt2
 
 
 def test_circular_has_proper_semimajor_axis():
@@ -204,6 +204,12 @@ def test_circular_has_proper_semimajor_axis():
     assert ss.a == expected_a
 
 
+def test_circular_raises_error_if_negative_altitude():
+    with pytest.raises(ValueError) as excinfo:
+        Orbit.circular(Earth, -1 * u.m, epoch=Time(0.0, format="jd", scale="tdb"))
+    assert "Altitude of an orbit cannot be negative." in excinfo.exconly()
+
+
 def test_geosync_has_proper_period():
     expected_period = 1436 * u.min
 
@@ -229,6 +235,7 @@ def test_parabolic_has_zero_energy():
     assert_allclose(ss.energy.value, 0.0, atol=1e-16)
 
 
+@pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_pqw_for_circular_equatorial_orbit():
     ss = Orbit.circular(Earth, 600 * u.km)
     expected_p = [1, 0, 0] * u.one
@@ -309,7 +316,7 @@ def test_frozen_orbit_no_args(attractor, alt, expected_inc, expected_argp):
         (
             Earth,
             1e6 * u.m,
-            2 * u.deg,  # Non critical value
+            2 * u.deg,  # Non-critical value
             63.4349 * np.pi / 180 * u.rad,
             None,
             0.0549 * u.one,
@@ -317,7 +324,7 @@ def test_frozen_orbit_no_args(attractor, alt, expected_inc, expected_argp):
         (
             Mars,
             3e8 * u.m,
-            0 * u.deg,  # Non critical value
+            0 * u.deg,  # Non-critical value
             63.4349 * np.pi / 180 * u.rad,
             0.04 * u.one,
             0.04 * u.one,
@@ -341,7 +348,7 @@ def test_frozen_orbit_venus_special_case():
     with pytest.raises(NotImplementedError) as excinfo:
         Orbit.frozen(Venus, 1 * u.m)
     assert excinfo.type == NotImplementedError
-    assert str(excinfo.value) == "This has not been implemented for Venus"
+    assert "This has not been implemented for Venus" in excinfo.exconly()
 
 
 def test_frozen_orbit_non_spherical_arguments():
@@ -349,8 +356,7 @@ def test_frozen_orbit_non_spherical_arguments():
         Orbit.frozen(Jupiter, 1 * u.m)
     assert excinfo.type == AttributeError
     assert (
-        str(excinfo.value)
-        == "Attractor Jupiter has not spherical harmonics implemented"
+        "Attractor Jupiter has not spherical harmonics implemented" in excinfo.exconly()
     )
 
 
@@ -358,10 +364,7 @@ def test_frozen_orbit_altitude():
     with pytest.raises(ValueError) as excinfo:
         Orbit.frozen(Earth, -1 * u.m)
     assert excinfo.type == ValueError
-    assert (
-        str(excinfo.value)
-        == "The semimajor axis may not be smaller that Earth's radius"
-    )
+    assert "Altitude of an orbit cannot be negative" in excinfo.exconly()
 
 
 def test_orbit_representation():
@@ -388,7 +391,9 @@ def test_sample_numpoints():
     _ = 0.5 * u.one  # Unused dimensionless value
     _a = 1.0 * u.deg  # Unused angle
     _body = Sun  # Unused body
-    ss = Orbit.from_classical(_body, _d, _, _a, _a, _a, _a)
+    ss = Orbit.from_classical(
+        attractor=_body, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+    )
     positions = ss.sample(values=50)
     assert len(positions) == 50
 
@@ -550,15 +555,6 @@ def test_orbit_from_custom_body_raises_error_when_asked_frame():
     )
 
 
-@pytest.mark.parametrize(
-    "body", [Sun, Mercury, Venus, Earth, Mars, Jupiter, Saturn, Uranus, Neptune]
-)
-def test_orbit_from_ephem_is_in_icrs_frame(body):
-    ss = Orbit.from_body_ephem(body)
-
-    assert ss.get_frame().is_equivalent_frame(ICRS())
-
-
 def test_orbit_accepts_ecliptic_plane():
     r = [1e09, -4e09, -1e09] * u.km
     v = [5e00, -1e01, -4e00] * u.km / u.s
@@ -602,121 +598,144 @@ def test_orbit_propagate_retains_plane():
     assert final_ss.get_frame().is_equivalent_frame(expected_frame)
 
 
-@pytest.mark.remote_data
-def test_from_horizons_raise_valueerror():
-    with pytest.raises(ValueError) as exep:
-        Orbit.from_horizons(name="Dummy", attractor=Sun)
-    assert (
-        "ValueError: Unknown target (Dummy). Maybe try different id_type?"
-        in exep.exconly()
-    )
-
-
-@pytest.mark.remote_data
-def test_orbit_from_horizons_has_expected_elements():
-    epoch = Time("2018-07-23", scale="tdb")
-    # Orbit Parameters of Ceres
-    # Taken from https://ssd.jpl.nasa.gov/horizons.cgi
-    ss = Orbit.from_classical(
-        Sun,
-        2.76710759221651 * u.au,
-        0.07554803091400027 * u.one,
-        27.18502494739172 * u.deg,
-        23.36913218336299 * u.deg,
-        132.2919809219236 * u.deg,
-        21.28957916690369 * u.deg,
-        epoch,
-    )
-    ss1 = Orbit.from_horizons(name="Ceres", attractor=Sun, epoch=epoch)
-    assert ss.pqw()[0].value.all() == ss1.pqw()[0].value.all()
-    assert ss.r_a == ss1.r_a
-    assert ss.a == ss1.a
-
-
-@pytest.mark.remote_data
-def test_plane_is_set_in_horizons():
-    plane = Planes.EARTH_ECLIPTIC
-    ss = Orbit.from_horizons(name="Ceres", attractor=Sun, plane=plane)
-    assert ss.plane == plane
-
-
 @pytest.mark.parametrize(
-    "attractor,angular_velocity,expected_a,expected_period",
+    "attractor,expected_a,expected_period",
     [
         (
             Earth,
-            (2 * np.pi / 23.9345) * u.rad / u.hour,
-            42_164_205 * u.m,
-            23.9345 * u.hour,
+            Earth.R + 35786 * u.km,
+            Earth.rotational_period,
         ),
         (
             Mars,
-            (2 * np.pi / 24.6228) * u.rad / u.hour,
-            20_427_595 * u.m,
-            24.6228 * u.hour,
+            Mars.R + 17031 * u.km,
+            Mars.rotational_period,
         ),
     ],
 )
-def test_geostationary_creation_from_angular_velocity(
-    attractor, angular_velocity, expected_a, expected_period
-):
-    ss = Orbit.geostationary(attractor=attractor, angular_velocity=angular_velocity)
-    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-7)
-    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-7)
+def test_stationary_orbit(attractor, expected_a, expected_period):
+    ss = Orbit.stationary(attractor=attractor)
+    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-4)
+    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-4)
 
 
 @pytest.mark.parametrize(
-    "attractor,period,expected_a",
+    "attractor,expected_a,expected_period",
     [
-        (Earth, 23.9345 * u.hour, 42_164_205 * u.m),
-        (Mars, 24.6228 * u.hour, 20_427_595 * u.m),
+        (
+            Earth,
+            Earth.R + 35786 * u.km,
+            Earth.rotational_period,
+        ),
+        (
+            Mars,
+            Mars.R + 17031 * u.km,
+            Mars.rotational_period,
+        ),
     ],
 )
-def test_geostationary_creation_from_period(attractor, period, expected_a):
-    ss = Orbit.geostationary(attractor=attractor, period=period)
-    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-7)
-    assert_quantity_allclose(ss.period, period, rtol=1.0e-7)
+def test_synchronous_orbit_without_ecc_and_inclination_given(
+    attractor, expected_a, expected_period
+):
+    ss = Orbit.synchronous(attractor=attractor)
+    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-4)
+    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-4)
 
 
 @pytest.mark.parametrize(
-    "attractor,period,hill_radius,expected_a",
+    "attractor,ecc,expected_a,expected_period",
     [
-        (Earth, 23.9345 * u.hour, 0.01 * u.AU, 42_164_205 * u.m),
-        (Mars, 24.6228 * u.hour, 1_000_000 * u.km, 20_427_595 * u.m),
+        (
+            Mercury,
+            0.0167 * u.one,
+            Mercury.R + 240453 * u.km,
+            Mercury.rotational_period,
+        ),
+        (
+            Jupiter,
+            0.0934 * u.one,
+            Jupiter.R + 88565 * u.km,
+            Jupiter.rotational_period,
+        ),
     ],
 )
-def test_geostationary_creation_with_Hill_radius(
-    attractor, period, hill_radius, expected_a
+def test_synchronous_orbit_without_inclination_given(
+    attractor, ecc, expected_a, expected_period
 ):
-    ss = Orbit.geostationary(
-        attractor=attractor, period=period, hill_radius=hill_radius
-    )
-    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-7)
-    assert_quantity_allclose(ss.period, period, rtol=1.0e-7)
-
-
-@pytest.mark.parametrize("attractor", [Earth, Mars])
-def test_geostationary_input(attractor):
-    with pytest.raises(ValueError) as excinfo:
-        Orbit.geostationary(attractor=attractor)
-
-    assert (
-        "ValueError: At least one among angular_velocity or period must be passed"
-        in excinfo.exconly()
-    )
+    ss = Orbit.synchronous(attractor=attractor, ecc=ecc)
+    assert_quantity_allclose(ss.ecc, ecc, rtol=1.0e-3)
+    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-3)
+    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-3)
 
 
 @pytest.mark.parametrize(
-    "attractor,period,hill_radius", [(Venus, 243.025 * u.day, 1_000_000 * u.km)]
+    "attractor,ecc,expected_a,expected_period",
+    [
+        (
+            Mercury,
+            1 * u.one,
+            Mercury.R + 240453 * u.km,
+            Mercury.rotational_period,
+        )
+    ],
 )
-def test_geostationary_non_existence_condition(attractor, period, hill_radius):
+def test_synchronous_orbit_pericenter_smaller_than_atractor_radius(
+    attractor, ecc, expected_a, expected_period
+):
     with pytest.raises(ValueError) as excinfo:
-        Orbit.geostationary(attractor=attractor, period=period, hill_radius=hill_radius)
+        Orbit.synchronous(attractor=attractor, ecc=ecc)
+    assert excinfo.type == ValueError
+    assert "The orbit for the given parameters doesn't exist" in excinfo.exconly()
 
-    assert (
-        "Geostationary orbit for the given parameters doesn't exist"
-        in excinfo.exconly()
-    )
+
+@pytest.mark.parametrize(
+    "attractor,ecc,expected_a,expected_period",
+    [
+        (
+            Mercury,
+            0.0167 * u.one,
+            2 ** (2 / 3) * (Mercury.R + 240453 * u.km),
+            2 * Mercury.rotational_period,
+        ),
+        (
+            Jupiter,
+            0.0934 * u.one,
+            2 ** (2 / 3) * (Jupiter.R + 88565 * u.km),
+            2 * Jupiter.rotational_period,
+        ),
+    ],
+)
+def test_synchronous_orbit_supersynchronous(
+    attractor, ecc, expected_a, expected_period
+):
+    ss = Orbit.synchronous(attractor=attractor, ecc=ecc, period_mul=2 * u.one)
+    assert_quantity_allclose(ss.ecc, ecc, rtol=1.0e-3)
+    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-3)
+    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-3)
+
+
+@pytest.mark.parametrize(
+    "attractor,ecc,expected_a,expected_period",
+    [
+        (
+            Mercury,
+            0.0167 * u.one,
+            0.5 ** (2 / 3) * (Mercury.R + 240453 * u.km),
+            0.5 * Mercury.rotational_period,
+        ),
+        (
+            Jupiter,
+            0.0934 * u.one,
+            0.5 ** (2 / 3) * (Jupiter.R + 88565 * u.km),
+            0.5 * Jupiter.rotational_period,
+        ),
+    ],
+)
+def test_synchronous_orbit_semisynchronous(attractor, ecc, expected_a, expected_period):
+    ss = Orbit.synchronous(attractor=attractor, ecc=ecc, period_mul=0.5 * u.one)
+    assert_quantity_allclose(ss.ecc, ecc, rtol=1.0e-3)
+    assert_quantity_allclose(ss.a, expected_a, rtol=1.0e-3)
+    assert_quantity_allclose(ss.period, expected_period, rtol=1.0e-3)
 
 
 def test_heliosynchronous_orbit_enough_arguments():
@@ -759,13 +778,38 @@ def test_heliosynchronous_orbit_a():
     assert_quantity_allclose(ss0.ecc, expected_ecc)
 
 
+def test_heliosynchronous_orbit_ecc():
+    # Vallado, example 11-2b
+    expected_ecc = 0.0 * u.one
+    expected_inc = 98.6 * u.deg
+    expected_a = 7178.1363 * u.km
+    ss0 = Orbit.heliosynchronous(Earth, a=expected_a, inc=expected_inc)
+
+    assert_quantity_allclose(ss0.inc, expected_inc, rtol=1e-4)
+    assert_quantity_allclose(ss0.a, expected_a, rtol=1e-5)
+    # Vallado uses a slightly different value for n_sunsync, hence `atol` needs to be added.
+    assert_quantity_allclose(ss0.ecc, expected_ecc, atol=1e-1)
+
+
+@pytest.mark.filterwarnings("ignore::RuntimeWarning")
+def test_heliosynchronous_orbit_raises_floating_point_error_if_invalid_input():
+    a = 0 * u.km
+    inc = 0 * u.rad
+
+    with pytest.raises(ValueError) as excinfo:
+        Orbit.heliosynchronous(Earth, a=a, inc=inc)
+    assert "No SSO orbit with given parameters can be found." in excinfo.exconly()
+
+
 def test_perigee_and_apogee():
     expected_r_a = 500 * u.km
     expected_r_p = 300 * u.km
     a = (expected_r_a + expected_r_p) / 2
     ecc = expected_r_a / a - 1
     _a = 1.0 * u.deg  # Unused angle
-    ss = Orbit.from_classical(Earth, a, ecc, _a, _a, _a, _a)
+    ss = Orbit.from_classical(
+        attractor=Earth, a=a, ecc=ecc, inc=_a, raan=_a, argp=_a, nu=_a
+    )
     assert_allclose(ss.r_a.to(u.km).value, expected_r_a.to(u.km).value)
     assert_allclose(ss.r_p.to(u.km).value, expected_r_p.to(u.km).value)
 
@@ -781,7 +825,9 @@ def test_expected_mean_anomaly():
     ecc = 0.37255 * u.one
     nu = 120 * u.deg
 
-    orbit = Orbit.from_classical(attractor, a, ecc, _a, _a, _a, nu)
+    orbit = Orbit.from_classical(
+        attractor=attractor, a=a, ecc=ecc, inc=_a, raan=_a, argp=_a, nu=nu
+    )
     orbit_M = E_to_M(nu_to_E(orbit.nu, orbit.ecc), orbit.ecc)
 
     assert_quantity_allclose(orbit_M, expected_mean_anomaly, rtol=1e-2)
@@ -798,7 +844,9 @@ def test_expected_angular_momentum():
     ecc = 0.37255 * u.one
     nu = 120 * u.deg
 
-    orbit = Orbit.from_classical(attractor, a, ecc, _a, _a, _a, nu)
+    orbit = Orbit.from_classical(
+        attractor=attractor, a=a, ecc=ecc, inc=_a, raan=_a, argp=_a, nu=nu
+    )
     orbit_h_mag = orbit.h_mag
 
     assert_quantity_allclose(orbit_h_mag.value, expected_ang_mag.value, rtol=1e-2)
@@ -815,7 +863,9 @@ def test_expected_last_perifocal_passage():
     ecc = 0.37255 * u.one
     nu = 120 * u.deg
 
-    orbit = Orbit.from_classical(attractor, a, ecc, _a, _a, _a, nu)
+    orbit = Orbit.from_classical(
+        attractor=attractor, a=a, ecc=ecc, inc=_a, raan=_a, argp=_a, nu=nu
+    )
     orbit_t_p = orbit.t_p
 
     assert_quantity_allclose(orbit_t_p, expected_t_p, rtol=1e-2)
@@ -834,7 +884,13 @@ def test_convert_from_rv_to_coe():
     expected_v = [4.902276, 5.533124, -1.975709] * u.km / u.s
 
     r, v = Orbit.from_classical(
-        attractor, p / (1 - ecc ** 2), ecc, inc, raan, argp, nu
+        attractor=attractor,
+        a=p / (1 - ecc ** 2),
+        ecc=ecc,
+        inc=inc,
+        raan=raan,
+        argp=argp,
+        nu=nu,
     ).rv()
 
     assert_quantity_allclose(r, expected_r, rtol=1e-5)
@@ -867,11 +923,14 @@ def test_convert_from_coe_to_rv():
     assert_quantity_allclose(nu, expected_nu, rtol=1e-4)
 
 
+@pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_perifocal_points_to_perigee():
     _d = 1.0 * u.AU  # Unused distance
     _ = 0.5 * u.one  # Unused dimensionless value
     _a = 1.0 * u.deg  # Unused angle
-    ss = Orbit.from_classical(Sun, _d, _, _a, _a, _a, _a)
+    ss = Orbit.from_classical(
+        attractor=Sun, a=_d, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+    )
     p, _, _ = ss.pqw()
     assert_allclose(p, ss.e_vec / ss.ecc)
 
@@ -883,6 +942,7 @@ def test_arglat_within_range():
     assert 0 * u.deg <= ss.arglat <= 360 * u.deg
 
 
+@pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_pqw_returns_dimensionless():
     r_0 = ([1, 0, 0] * u.au).to(u.km)  # type: ignore
     v_0 = ([0, 6, 0] * u.au / u.year).to(u.km / u.day)
@@ -994,29 +1054,6 @@ def test_from_coord_if_coord_is_not_of_shape_zero():
     assert_quantity_allclose(ss.v, vel * u.km / u.s, rtol=1e-5)
 
 
-@pytest.mark.remote_data
-@pytest.mark.parametrize(
-    "target_name", ["Ceres", "Vesta", "Eros"]
-)  # Objects in both JPL SBDB and JPL Horizons
-def test_from_sbdb_and_from_horizons_give_similar_results(target_name):
-    ss_target = Orbit.from_sbdb(target_name)
-    ss_classical = ss_target.classical()
-
-    ss_ref = Orbit.from_horizons(
-        name=target_name, attractor=Sun, plane=Planes.EARTH_ECLIPTIC
-    )
-
-    ss_ref = ss_ref.propagate_to_anomaly(
-        ss_classical[5]
-    )  # Catch reference orbit to same epoch
-    ss_ref_class = ss_ref.classical()
-
-    for test_elm, ref_elm in zip(ss_classical, ss_ref_class):
-        assert_quantity_allclose(
-            test_elm, ref_elm, rtol=1e-2
-        )  # Maximum error of 1% (chosen arbitrarily)
-
-
 def test_propagate_to_anomaly_gives_expected_result():
     # From "Going to Jupiter with Python using Jupyter and poliastro.ipynb"
     ic1 = Orbit.from_vectors(
@@ -1054,8 +1091,8 @@ def test_from_sbdb_raise_valueerror():
         Orbit.from_sbdb(name="Halley")
 
     assert (
-        str(excinfo.value)
-        == "2 different objects found: \n2688 Halley (1982 HG1)\n1P/Halley\n"
+        "2 different objects found: \n2688 Halley (1982 HG1)\n1P/Halley"
+        in excinfo.exconly()
     )
 
 
@@ -1087,18 +1124,12 @@ def test_from_classical_wrong_dimensions_fails():
     _a = 1.0 * u.deg  # Unused angle
 
     with pytest.raises(ValueError) as excinfo:
-        Orbit.from_classical(Earth, bad_a, _, _a, _a, _a, _a)
+        Orbit.from_classical(
+            attractor=Earth, a=bad_a, ecc=_, inc=_a, raan=_a, argp=_a, nu=_a
+        )
     assert "ValueError: Elements must be scalar, got [1.] AU" in excinfo.exconly()
 
 
-@pytest.mark.remote_data
-def test_orbit_change_attractor():
-    Io = 501  # Id for Io moon
-    ss_io = Orbit.from_horizons(Io, Sun, epoch=J2000, id_type="majorbody")
-    ss_io = ss_io.change_attractor(Jupiter)
-    assert Jupiter == ss_io.attractor
-
-
 def test_orbit_change_attractor_returns_self():
     assert iss.change_attractor(iss.attractor) is iss
 
@@ -1123,8 +1154,10 @@ def test_orbit_change_attractor_force():
         v=[-13.30694373, 25.15256978, 11.59846936] * u.km / u.s,
         epoch=J2000,
     )
-
-    ss_new_attractor = ss.change_attractor(Earth, force=True)
+    with pytest.warns(
+        PatchedConicsWarning, match="Leaving the SOI of the current attractor"
+    ):
+        ss_new_attractor = ss.change_attractor(Earth, force=True)
     assert ss_new_attractor.attractor == Earth
 
 
@@ -1148,12 +1181,11 @@ def test_orbit_change_attractor_open():
     v = [-15.457, 6.618, 2.533] * u.km / u.s
     ss = Orbit.from_vectors(Earth, r, v)
 
-    with pytest.warns(PatchedConicsWarning) as record:
+    with pytest.warns(
+        PatchedConicsWarning, match="Leaving the SOI of the current attractor"
+    ):
         ss.change_attractor(Sun)
 
-    w = record.pop(PatchedConicsWarning)
-    assert "Leaving the SOI of the current attractor" in w.message.args[0]
-
 
 @pytest.mark.parametrize(
     "expected_plane", [Planes.EARTH_ECLIPTIC, Planes.EARTH_EQUATOR]
@@ -1201,9 +1233,10 @@ def test_time_to_anomaly(expected_nu):
 def test_can_set_iss_attractor_to_earth():
     # See https://github.com/poliastro/poliastro/issues/798
     epoch = Time("2019-11-10 12:00:00")
-    iss = Orbit.from_horizons(
-        "International Space Station", Sun, epoch=epoch, id_type="majorbody"
+    ephem = Ephem.from_horizons(
+        "International Space Station", epochs=epoch, attractor=Sun, id_type=None
     )
+    iss = Orbit.from_ephem(Sun, ephem, epoch)
     iss = iss.change_attractor(Earth)
     assert iss.attractor == Earth
 
@@ -1220,7 +1253,7 @@ def test_issue_916(mock_query):
     )
     with pytest.raises(ValueError) as excinfo:
         Orbit.from_sbdb(name)
-    assert "ValueError: Object {} not found".format(name) in excinfo.exconly()
+    assert f"ValueError: Object {name} not found" in excinfo.exconly()
 
 
 def test_near_parabolic_M_does_not_hang(near_parabolic):
